==> Glossary-0.6.7.tar.gz: Glossary/method.upgrade.php <==
<?php
#-------------------------------------------------------------------------
# Module: Glossary / Dictionary / FAQ module
# Version: 0.6.6, SjG
# http://dev.cmsmadesimple.org/projects/glossary
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2009 by Ted Kulp (ted@cmsmadesimple.org)
# http://www.cmsmadesimple.org
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------

$db = &$this->GetDb();
$taboptarray = array('mysql' => 'TYPE=MyISAM');
$dict = NewDataDictionary($db);
$current_version = $oldversion;
switch($current_version)
  {
  case "0.1":
    $current_version = "0.1";
  case "0.5":
    $this->RemovePreference('filter_type');
  }

// put mention into the admin log
$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('upgraded',$this->GetVersion()));

# EOF
?>

==> Glossary-1.0.tar.gz: Glossary/method.upgrade.php <==
<?php
#-------------------------------------------------------------------------
# Module: Glossary / Dictionary / FAQ module
# Version: 0.6.6, SjG
# http://dev.cmsmadesimple.org/projects/glossary
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2009 by Ted Kulp (ted@cmsmadesimple.org)
# http://www.cmsmadesimple.org
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------

$db = cmsms()->GetDb();
$taboptarray = array('mysql' => 'TYPE=MyISAM');
$dict = NewDataDictionary($db);
$current_version = $oldversion;
switch($current_version)
  {
  case "0.1":
  case "0.5":
    $this->RemovePreference('filter_type');
  case "0.5.1":
  case "0.6":
  case "0.6.1":
  case "0.6.2":
  case "0.6.3":
  case "0.6.4":
  case "0.6.5":
  case "0.6.6":
  case "0.6.7":
  case "0.6.8":
  case "0.7":
	$sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_glossary_term", "tip C(255)");
	$dict->ExecuteSQLArray($sqlarray);
	$sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_glossary_term", "create_date ". CMS_ADODB_DT);
	$dict->ExecuteSQLArray($sqlarray);
	$db->Execute('UPDATE '.cms_db_prefix().'module_glossary_term SET create_date = ?', array(trim($db->DBTimeStamp(time()), "'")));
  }

// put mention into the admin log
$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('upgraded',$this->GetVersion()));

?>
